package com.ruoyi.doubledefense.service;

import java.util.List;
import com.ruoyi.doubledefense.domain.Hazard;
import com.ruoyi.doubledefense.dto.HazardDTO;
import com.ruoyi.doubledefense.dto.HazardStatisticsDTO;
import com.ruoyi.doubledefense.dto.res.HazardResultDTO;

/**
 * 风险分析对象Service接口
 *
 * @author ruoyi
 * @date 2023-08-03
 */
public interface IHazardService
{
    /**
     * 查询风险分析对象
     *
     * @param id 风险分析对象主键
     * @return 风险分析对象
     */
    public HazardResultDTO selectHazardById(String id);

    /**
     * 查询风险分析对象列表
     *
     * @param hazardDTO 风险分析对象
     * @return 风险分析对象集合
     */
    public List<HazardResultDTO> selectHazardList(HazardDTO hazardDTO);

    /**
     * 新增风险分析对象
     *
     * @param hazardDTO 风险分析对象
     * @return 结果
     */
    public int insertHazard(HazardDTO hazardDTO);

    /**
     * 修改风险分析对象
     *
     * @param hazardDTO 风险分析对象
     * @return 结果
     */
    public int updateHazard(HazardDTO hazardDTO);

    /**
     * 批量删除风险分析对象
     *
     * @param ids 需要删除的风险分析对象主键集合
     * @return 结果
     */
    public int deleteHazardByIds(String[] ids);

    /**
     * 风险管理统计
     * APP首页统计
     * @return
     */
    HazardStatisticsDTO riskStatistics();

    /**
     * 统计数量
     * @param companyCode
     * @return
     */
    Long countHazard(String companyCode);
}
